@@ -3,7 +3,9 @@
 import threading
 import logging
 import sys
-from core import AquaLogic, States
+
+from .core import AquaLogic
+from .states import States
 
 logging.basicConfig(level=logging.INFO)
 
